@@ -1,13 +1,41 @@
 -- 
 -- Created by SQL::Translator::Producer::MySQL
--- Created on Thu May 11 15:06:58 2017
+-- Created on Sat May 27 00:18:10 2017
 -- 
 SET foreign_key_checks=0;
 
+DROP TABLE IF EXISTS `metabase_user`;
+
+--
+-- Table: `metabase_user`
+--
+CREATE TABLE `metabase_user` (
+  `id` integer NOT NULL auto_increment,
+  `resource` char(50) NOT NULL,
+  `fullname` varchar(255) NOT NULL,
+  `email` varchar(255) NULL,
+  PRIMARY KEY (`id`),
+  UNIQUE `metabase_user_resource` (`resource`)
+);
+
+DROP TABLE IF EXISTS `test_report`;
+
+--
+-- Table: `test_report`
+--
+CREATE TABLE `test_report` (
+  `id` char(36) NOT NULL,
+  `created` datetime NOT NULL,
+  `report` JSON NOT NULL,
+  PRIMARY KEY (`id`)
+);
+
+DROP TABLE IF EXISTS `uploads`;
+
 --
 -- Table: `uploads`
 --
-CREATE TABLE IF NOT EXISTS `uploads` (
+CREATE TABLE `uploads` (
   `uploadid` integer unsigned NOT NULL auto_increment,
   `type` varchar(255) NOT NULL,
   `author` varchar(255) NOT NULL,
@@ -18,34 +46,38 @@ CREATE TABLE IF NOT EXISTS `uploads` (
   PRIMARY KEY (`uploadid`)
 ) ENGINE=InnoDB;
 
+DROP TABLE IF EXISTS `cpanstats`;
+
 --
 -- Table: `cpanstats`
 --
-CREATE TABLE IF NOT EXISTS `cpanstats` (
+CREATE TABLE `cpanstats` (
   `id` integer unsigned NOT NULL auto_increment,
   `guid` char(36) NOT NULL,
   `state` enum('pass', 'fail', 'unknown', 'na') NOT NULL,
   `postdate` mediumint unsigned NOT NULL,
-  `tester` varchar(255) NOT NULL,
-  `dist` varchar(255) NOT NULL,
-  `version` varchar(255) NOT NULL,
-  `platform` varchar(255) NOT NULL,
-  `perl` varchar(255) NOT NULL,
-  `osname` varchar(255) NOT NULL,
-  `osvers` varchar(255) NOT NULL,
-  `fulldate` varchar(32) NOT NULL,
+  `tester` varchar(100) NOT NULL,
+  `dist` varchar(100) NOT NULL,
+  `version` varchar(20) NOT NULL,
+  `platform` varchar(20) NOT NULL,
+  `perl` varchar(10) NOT NULL,
+  `osname` varchar(20) NOT NULL,
+  `osvers` varchar(20) NOT NULL,
+  `fulldate` char(8) NOT NULL,
   `type` tinyint unsigned NOT NULL,
   `uploadid` integer unsigned NOT NULL,
   INDEX `cpanstats_idx_uploadid` (`uploadid`),
   PRIMARY KEY (`id`),
-  UNIQUE KEY (`guid`),
+  UNIQUE `cpanstats_guid` (`guid`),
   CONSTRAINT `cpanstats_fk_uploadid` FOREIGN KEY (`uploadid`) REFERENCES `uploads` (`uploadid`)
 ) ENGINE=InnoDB;
 
+DROP TABLE IF EXISTS `ixlatest`;
+
 --
 -- Table: `ixlatest`
 --
-CREATE TABLE IF NOT EXISTS `ixlatest` (
+CREATE TABLE `ixlatest` (
   `dist` varchar(255) NOT NULL,
   `author` varchar(255) NOT NULL,
   `version` varchar(255) NOT NULL,
@@ -57,10 +89,12 @@ CREATE TABLE IF NOT EXISTS `ixlatest` (
   CONSTRAINT `ixlatest_fk_uploadid` FOREIGN KEY (`uploadid`) REFERENCES `uploads` (`uploadid`)
 ) ENGINE=InnoDB;
 
+DROP TABLE IF EXISTS `release_data`;
+
 --
 -- Table: `release_data`
 --
-CREATE TABLE IF NOT EXISTS `release_data` (
+CREATE TABLE `release_data` (
   `dist` varchar(255) NOT NULL,
   `version` varchar(255) NOT NULL,
   `id` integer NOT NULL,
@@ -79,10 +113,12 @@ CREATE TABLE IF NOT EXISTS `release_data` (
   CONSTRAINT `release_data_fk_uploadid` FOREIGN KEY (`uploadid`) REFERENCES `uploads` (`uploadid`)
 ) ENGINE=InnoDB;
 
+DROP TABLE IF EXISTS `release_summary`;
+
 --
 -- Table: `release_summary`
 --
-CREATE TABLE IF NOT EXISTS `release_summary` (
+CREATE TABLE `release_summary` (
   `dist` varchar(255) NOT NULL,
   `version` varchar(255) NOT NULL,
   `id` integer NOT NULL,
